@@ -1,4 +1,4 @@
-/* Copyright (C) 1999-2019 Free Software Foundation, Inc.
+/* Copyright (C) 1999-2025 Free Software Foundation, Inc.
 
    This file is part of GDB.
 
@@ -15,8 +15,8 @@
    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
 
-#ifndef AARCH32_LINUX_NAT_H
-#define AARCH32_LINUX_NAT_H
+#ifndef GDB_AARCH32_LINUX_NAT_H
+#define GDB_AARCH32_LINUX_NAT_H
 
 void aarch32_gp_regcache_supply (struct regcache *regcache, uint32_t *regs,
 				 int arm_apcs_32);
@@ -31,4 +31,4 @@ void aarch32_vfp_regcache_collect (const struct regcache *regcache,
 				   gdb_byte *regs,
 				   const int vfp_register_count);
 
-#endif /* AARCH32_LINUX_NAT_H */
+#endif /* GDB_AARCH32_LINUX_NAT_H */
